@@ -8,7 +8,7 @@
     'name_es_ES': 'Partes de trabajo',
     'name_fr_FR': 'Feuille de présence',
     'name_nl_NL': 'Tijdregistratie',
-    'version': '2.0.2',
+    'version': '2.2.2',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -87,11 +87,13 @@ Bijbehorende rapporten:
         'line.xml',
     ],
     'translation': [
-        'bg_BG.csv',
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
-        'nl_NL.csv',
+        'locale/cs_CZ.po',
+        'locale/bg_BG.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
